package SeMeet::Controller::Records;
use Mojo::Base 'Mojolicious::Controller', -signatures;

use constant FILENAME_REGEX => qr/(.+)_(\d{4})\-(\d{2})\-(\d{2})\-(\d{2})\-(\d{2})\-(\d{2})\.mp4/;

sub create($c) {
    $c->openapi->valid_input or return;
    my $args = $c->req->json;

    # datum meetu
    if ($args->{file} !~ FILENAME_REGEX) {
        return $c->error(400, 'INVALID FILENAME');
    }
    my $recorded = "$2-$3-$4 $5:$6:$7";

    # Duplicita id
    my $exists = $c->schema->resultset('Record')->count({
        deleted => undef,
        uuid    => $args->{uuid},
    });
    return $c->error(400, 'DUPLICTE UUID') if $exists;

    # meet
    my $meet_uuid = $args->{meeting_url};
    $meet_uuid =~ s/.+\///;
    my $meet = $c->schema->resultset('Meet')->search({
        uuid => $meet_uuid
    })->first;

    return $c->error(400, 'MEET NOT FOUND') if ! $meet;

    my $guard  = $c->schema->txn_scope_guard;

        $meet->add_to_records({
            uuid     => $args->{uuid},
            file     => $args->{file},
            recorded => $recorded,
        });

    $guard->commit;

#    $c->trace(\'Record %s create meet "%s" with id %d',
#        $c->stash->{user}->username,
#        $meet->name,
#        $meet->id,
#    );

    $c->render( status  => 204, text => '' );
}

1;
